@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Dir::Split qw(split_dir);
 
-our(%form, %form_o);
+our (%Form, %Form_opt);
 my $return = -255;
 
 
@@ -21,17 +21,16 @@ my %num_options = (
    source  =>    '/source',
    target  =>    '/target',
  
-   options => {  verbose     =>           1,
-                 override    =>           0,
-   },
-   sub_dir => {  identifier  =>       'sub',
-                 file_limit  =>           2,
-                 file_sort   =>         '+',
-   },
-   suffix  => {  separator   =>         '-',
-                 continue    =>           1,
-                 length      =>           5,
-   },
+   verbose     =>        1,
+   override    =>        0,
+
+   identifier  =>    'sub',
+   file_limit  =>        2,
+   file_sort   =>      '+',
+   
+   separator   =>      '-',
+   continue    =>        1,
+   length      =>        5,
 );
 
 my %char_options = (  
@@ -40,15 +39,15 @@ my %char_options = (
    source  =>    '/source',
    target  =>    '/target',
 
-   options => {  verbose     =>           1,
-                 override    =>           0,
-   },
-   sub_dir => {  identifier  =>       'sub',
-   },
-   suffix  => {  separator   =>         '-',
-                 case        =>     'upper',
-                 length      =>           1,
-   },
+   verbose     =>          1,
+   override    =>          0,
+  
+   identifier  =>      'sub',
+
+   separator   =>        '-',
+   case        =>    'upper',
+   length      =>          1,
+
 );
 
 
@@ -61,11 +60,11 @@ my %char_options = (
 
 # numeric splitting
 #
-#$return = split_dir(%num_options);
+#$return = split_dir( %num_options );
 
 # characteristic splitting
 #
-#$return = split_dir(%char_options);
+#$return = split_dir( %char_options );
 
 
 
@@ -73,56 +72,60 @@ my %char_options = (
 ###############
 
 # action
-if ($return == 1) { formwrite('track') }
+if ($return == 1) { 
+    formwrite( 'track' );
+}
 # no action
-elsif ($return == 0) { print "None moved.\n" }
+elsif ($return == 0) { 
+    print "None moved.\n";
+}
 # existing files
 elsif ($return == -1) {
-    local %form_o;
+    local %Form_opt;
 
-    $form_o{header} = 'EXISTS';
-    $form_o{ul} = '-' x length($form_o{header});
+    $Form_opt{header} = 'EXISTS';
+    $Form_opt{ul} = '-' x length( $Form_opt{header} );
      
-    formwrite('start_debug');
+    formwrite( 'start_debug' );
 
     for my $file (@Dir::Split::exists) {
         print "file:\t$file\n";
     }
     
-    formwrite('end_debug'); 
-    formwrite('track');
+    formwrite( 'end_debug' ); 
+    formwrite( 'track' );
 }
 # copy or unlink failure
 elsif ($return == -2) {
-    local %form_o;
+    local %Form_opt;
 
     if (@Dir::Split::exists) {
-        $form_o{header} = 'EXISTS';
-        $form_o{ul} = '-' x length($form_o{header});
+        $Form_opt{header} = 'EXISTS';
+        $Form_opt{ul} = '-' x length( $Form_opt{header} );
 	
-        formwrite('start_debug');
+        formwrite( 'start_debug' );
 
         for my $file (@Dir::Split::exists) {
             print "file:\t$file\n";
         }
 	
-	formwrite('end_debug');
+	formwrite( 'end_debug' );
     }
     
-    $form_o{header} = 'FAILURE';
-    $form_o{ul} = '-' x length($form_o{header});
+    $Form_opt{header} = 'FAILURE';
+    $Form_opt{ul} = '-' x length( $Form_opt{header} );
     
-    formwrite('start_debug');
+    formwrite( 'start_debug' );
     
-    for my $file (@{$Dir::Split::failure{copy}}) {
+    for my $file (@{ $Dir::Split::failure{copy} }) {
         print "copy failed:\t$file\n";
     }
-    for my $file (@{$Dir::Split::failure{unlink}}) {
+    for my $file (@{ $Dir::Split::failure{unlink} }) {
         print "unlink failed:\t$file\n";
     }
     
-    formwrite('end_debug');
-    formwrite('track');
+    formwrite( 'end_debug' );
+    formwrite( 'track' );
 }
 # no config
 else {
@@ -130,16 +133,16 @@ else {
 }
 
 sub formwrite {
-    my($ident) = @_;
+    my ($ident) = @_;
     
     no warnings 'redefine';
-    eval $form{$ident};
+    eval $Form{$ident};
     die $@ if $@;
     write;
 }
 
 BEGIN {
-    $form{track} = 'format = 
+    $Form{track} = 'format = 
 -------------------
 source - files: @<<<
 sprintf "%3d", $Dir::Split::track{source}{files}
@@ -150,21 +153,21 @@ sprintf "%3d", $Dir::Split::track{target}{dirs}
 -------------------
 .';
 
-    $form{start_debug} = 'format =
+    $Form{start_debug} = 'format =
 ---------------@<<<<<<<<<<
-$form_o{ul}
+$Form_opt{ul}
 START: DEBUG - @<<<<<<<<<<
-$form_o{header}
+$Form_opt{header}
 ---------------@<<<<<<<<<<
-$form_o{ul} 
+$Form_opt{ul} 
 .';
     
-    $form{end_debug} = 'format =
+    $Form{end_debug} = 'format =
 ---------------@<<<<<<<<<<
-$form_o{ul}
+$Form_opt{ul}
 END  : DEBUG - @<<<<<<<<<<
-$form_o{header}
+$Form_opt{header}
 ---------------@<<<<<<<<<<
-$form_o{ul} 
+$Form_opt{ul} 
 .';    
 }
